The current program is an application of the SALI (Smaller Alignment Index) method 
for calculation of regular/chaotic areas in phase space of hamiltonian systems. It 
evaluate the area for a 2D optical lattice hamiltonian system, but it is of generic 
use for conservative hamiltonian systems.

The SALI method is completely based on the work of C. Skokos, as exposed in the 
reference: Ch Skokos et al 2004 J. Phys. A: Math. Gen.37 6269

The code is implemented in C/C++, requiring libraries GSL and OpenMP to be installed
(more in Install section).

Header files `.hpp` can be found at `include/` and source files `.cpp` at `\src/`. 
Python scripts for data plotting are stored in `plt/` folder.

Implemented by: M. Lazarotto (matheus.lazarotto@usp.br) 
(Last update 26/05/2020)

## Run
In order to use the program, just run the bash script with `bash bash_run.sh`. You can 
edit the bash script to change the simulation settings. From bash script, the simulation 
will calculate the chaotic and regular areas over a Poincaré Surface Section (PSS) for 
a series of [nFrm] energy values, ranging from [Emin] to [Emax]. As output, the code 
returns `.dat` files with the simulated data, stored at `dat/` folder, and the plot images 
of it in `.png` format, stored at `img/` folder. In case the calculation is interrupted 
midway, it can be resumed from where it stopped by setting [init] in `bash_run.sh` to 
the last value simulated (the final `area.dat` file will be appended in this case).

A grid matrix over the PSS, with dimensions [Nx] by [Npx], is used as initial points 
position; the higher the grid points, the better the precision in area calculation.
The grid points are also used to avoid redundant calculations and save CPU time 
(see `grid.cpp` and `grid.hpp`).

The code is parallelized with OpenMP directives, and the number of threads is selected 
in [nThreads] ([nThreads=-1] select all threads available dynamically; for a fixed amount 
of threads, set a particular value).

In case one needs to compile the program manually, just type `make` in the working  
folder and `./run_sali` to run it. When running `./run_sali`, a series of positional 
arguments must be given (information for each arg is given at `bash_run.sh` and 
`main_sali.cpp`):

`./run_sali [iN] [ie] [a] [Emin] [Emax] [Ngrid_x] [Ngrid_px] [nThreads]`

Further parameters of the method, such as the PSS position, maximum evolution time etc. 
can be altered inside `main_sali.cpp` file.

## Install
The whole compilation is made by the `Makefile`, requiring the command 

`make` 

in the program folder. `make clean` delete any current executable of older compilations.

The numerical integration is made from the ODE solver package from GSL (https://www.gnu.org/software/gsl/), 
thus requiring it to be installed in the computer. From ubuntu, one can quickly install 
GSL from the repository with the following command:

`sudo apt-get install libgsl-dev`

For parallelized thread computation, OpenMP library was used. Its installation can be made 
from the Ubuntu repository with:

`sudo apt-get install libomp-dev`

