#!/bin/bash

# Bash script for calculation of stable/chaotic 
# areas over Poincaré Surface Sections (PSS) for
# the 2D optical lattice system. 
#
# The settings below can be edited. This bash 
# script runs the 
#
#
# Made by: M. Lazarotto (26/05/2020)

###################################################
#---------------- SETTINGS -----------------------#
###################################################
alpha="0.50"        # Coupling (perturbation)
Emin="22.0"         # Min energy interval
Emax="28.0"         # Max energy interval
Nx=19               # Grid columns
Npx=19              # Grid rows
init=0              # Initial energy index
nFrm=5             # Total energy index vals
nThreads=-1         # Number of threads to run
###################################################
#-------------------------------------------------#
###################################################

# Compilation
make clean  # Clear current executable
clear       # Clear terminal screen
make        # Compile new executable

# If it's a new run, starts from existing files
# Otherwise continues were it stopped.
if [ $init == 0 ]
then
    if [ -f "area.dat" ]
    then
        rm area.dat
    fi

    # Create output file with area values
    > area.dat
    # Write output file header
    echo '# Chaotic/Stable areas' >> area.dat
    echo '# alpha = '$alpha >> area.dat
    echo '# Emin = '$Emin >> area.dat
    echo '# Emax = '$Emax >> area.dat
    echo '# nFrm = '$nFrm >> area.dat
    echo '# Nx   = '$Nx  >> area.dat
    echo '# Npx  = '$Npx >> area.dat
    echo '# [E]    [A_s]   [A_c]   [A_T]   [A_s_norm]   [A_c_norm]' >> area.dat
fi

# If compiled successfully -> run it
if [ -e "./run_sali" ]
then
    clear
    date
    for (( i=$init; i <= $nFrm; i++ ))
    do
        # Print progress in terminal
        echo "Parameter set: [ $i / $nFrm ]"
        # Run SALI code
        ./run_sali $nFrm $i $alpha $Emin $Emax $Nx $Npx $nThreads
        # Plot SALI PSS map
        python3.6 plt/plot_sali.py
        # Move files
        mv sali_**.dat dat/
        mv sali_**.png img/
    done
    
    # Plot Area per energy
    python3.6 plt/plot_area.py -fl area.dat
    date
fi