#ifndef _AUXF_H_
#define _AUXF_H_

#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <iostream>
#include <vector>

#include <gsl/gsl_errno.h>
#include <gsl/gsl_math.h>
#include <gsl/gsl_matrix.h>
#include <gsl/gsl_odeiv2.h>

using namespace std;

void print_Vf(vector<double> v);
vector<double> arr_to_vec(double arr[], unsigned int n);
vector<int> linspace_i(int xi, int xf = 1, unsigned int skip = 1);
vector<double> linspace_f(double xi, double xf, unsigned int N);

double norm(vector<double> v);
void normalize(vector<double> &v);
vector<double> lincomb_f(double a, vector<double> v1, double b, vector<double> v2);

double V(double x, double y, double U, double a);
double Ham(double x, double y, double px, double py, double U, double a);
double dqdt(double pi);
double dpdt(double qi, double qj, double U, double a);
double Vi(double qi, double qj, double U, double a);
double Vii(double qi, double qj, double U, double a);
double Vij(double qi, double qj, double U, double a);
double Viii(double qi, double qj, double U, double a);
double Viij(double qi, double qj, double U, double a);
double Viji(double qi, double qj, double U, double a);

int system_funct(double t, const double s[], double f[], void *args);
int system_jacob(double t, const double s[], double *dfdy, double dfdt[], void *args);
int system_funct_lin(double t, const double s[], double f[], void *args);
int system_jacob_lin(double t, const double s[], double *dfdy, double dfdt[], void *args);
int system_funct_all(double t, const double s[], double f[], void *args);
int system_jacob_all(double t, const double s[], double *dfdy, double dfdt[], void *args);

int pss_henon_step(unsigned int dimS, double mi_s, double varp[], double *args);

#endif
