#ifndef _GRID_H_
#define _GRID_H_

#include <cassert>
#include <cmath>
#include <vector>

using namespace std;

/**
 * The Grid object is a 2D matrix that stores at each 
 * point [i,j] a vector with dimension [grid_dim_pt >= 2].
 * The grid is made over a region of the 'real' space,
 * within the limits [x_min, x_max] x [y_min, y_max],
 * hence each point of the grid is mapped into a point
 * in the float space.
 **/

class Grid
{
    public:
        Grid(unsigned int width, 
             unsigned int height,
             double x_min, double x_max, 
             double y_min, double y_max,
             unsigned int pt_dim = 2);

		bool check_empty_flt_neigh(double sX, double sY, unsigned int Neig);
        bool check_empty_ndx_neigh(unsigned int i, unsigned int j, unsigned int Neig);
        bool check_empty_flt(double sX, double sY);
        bool check_empty_ndx(unsigned int i, unsigned int j);
        void set_grid_pt_ndx(unsigned int i, unsigned int j, vector<double> pt);
        void set_grid_pt_flt(double sX, double sY, vector<double> pt);
        vector<double> get_grid_pt(unsigned int i, unsigned int j);
        vector<int> get_grid_ndx(double sX, double sY);

        /* Space boundaries */
        double sX_min;
        double sX_max;
        double sY_min;
        double sY_max;
        
        /* Grid dimensions */
        unsigned int gWidth;
        unsigned int gHeight;
        unsigned int gPoint_dim;

        double empty_val = -9999.9;
        vector<vector<vector<double>>> grid; 
        
};

#endif
