#include "ode_sys_solv.hpp"

int ode_step_cntrl(gsl_odeiv2_evolve *evolve, gsl_odeiv2_control *control, 
                   gsl_odeiv2_step *step, gsl_odeiv2_system &sys, 
                   double &t, double &dt, double t_max, double *s,
                   double modX_inf, double modX_top, 
                   double modY_inf, double modY_top)
{
    /** performs ode step from [t] to [t_max] with precision control and 
     *  return success status **/    
    int status = gsl_odeiv2_evolve_apply(evolve, control, step, 
                                         &sys, &t, t_max, &dt, s);

    /** Modulation **/
    if (s[0] >= modX_top) 
    { 
        s[0] = s[0] - (modX_top - modX_inf); 
    } 
    else if (s[0] <= modX_inf) 
    { 
        s[0] = s[0] + (modX_top - modX_inf); 
    }

    if (s[1] >= modY_top) 
    { 
        s[1] = s[1] - (modY_top - modY_inf); 
    } 
    else if (s[1] <= modY_inf) 
    { 
        s[1] = s[1] + (modY_top - modY_inf); 
    }
    
    return status;
}

int ode_step_fixed(gsl_odeiv2_driver *driver, double &t, double dt, double *s, 
                   double modX_inf, double modX_top, double modY_inf, double modY_top, int nSteps) 
{
    /** performs [nSteps] ODE steps with fixed time step and return success 
     *  status **/    
    int status = gsl_odeiv2_driver_apply_fixed_step(driver, &t, dt, nSteps, s);

    /** Modulation **/
    if (s[0] >= modX_top) 
    { 
        s[0] = s[0] - (modX_top - modX_inf); 
    } 
    else if (s[0] <= modX_inf) 
    { 
        s[0] = s[0] + (modX_top - modX_inf); 
    }

    if (s[1] >= modY_top) 
    { 
        s[1] = s[1] - (modY_top - modY_inf); 
    } 
    else if (s[1] <= modY_inf) 
    { 
        s[1] = s[1] + (modY_top - modY_inf); 
    }
    
    return status;
}